@@ -92,6 +92,9 @@ def openlight():  # Enable the backlight
 	BUS.write_byte(I2C_LCD,0x08)
 	BUS.close()
 
+def lightoff():
+	pcf.port[0] = True
+
 def write(x, y, str):
 	if x < 0:
 		x = 0
@@ -109,15 +112,27 @@ def write(x, y, str):
 	for chr in str:
 		send_data(ord(chr))
 
+def setup():
+	init(I2C_LCD, 1)
+	# lightoff()
+
+def test_lcd():
+
+	for i in range(16):
+
+		clear()
+		write((4+i)%16, 0, 'Hello')
+		write((7+i)%16, 1, 'world!')
+		time.sleep(0.3)
+
+
 if __name__ == '__main__':
 
-	pcf.port[0] = True # controls light off
-	time.sleep(2)
-
-	init(I2C_LCD, 1)
-	write(4, 0, 'Hello')
-	#write(7, 1, 'world!')
-
-	time.sleep(2)
-	pcf.port[0] = True
+	setup()
 
+	try:
+		# openlight()
+		while True:
+			test_lcd()
+	except KeyboardInterrupt:
+		lightoff()
