@@ -44,11 +44,9 @@ else:
 '''
 
 RUNNING = True
-
-# TODO: assign a pin to sos 
-
 SPEED = 40 # controls vehicle speed
 TIME = 0.2
+SAFE_DISTANCE = 40
 ENABLE_BUTTON = True # onboard yellow cap switch
 ENABLE_SONIC2 = True # 超声2 and BACK Collision share GPIO 13 and 26
 
@@ -163,7 +161,9 @@ def keyscan():
         led.test_led(R_val = 40, G_val = 0, B_val = 0)
         led.test_led(R_val = 0, G_val = 70, B_val =0)
         led.test_led(R_val = 0, G_val = 0, B_val = 90)
-    
+        # print(front_detection(), back_detection())
+        # time.sleep(0.5)
+
     time.sleep(0.1) # after start, set green light on and red off
     return
 
@@ -233,7 +233,8 @@ def setup():
     # # test fall and collision
     # print( fall_detection() )
     # print( collision_detection() )    
-    print_used_pins()
+    # print_used_pins()
+    print(front_detection(), back_detection())
 
 def distance(pin_trig = TRIG, pin_echo = ECHO):
 
@@ -248,10 +249,13 @@ def distance(pin_trig = TRIG, pin_echo = ECHO):
     time1 = time.time()
     while GPIO.input(pin_echo) == 1:
         a = 1
+        time2 = time.time()
+        if time2 - time1 > 0.2: # wait 0.2s at most, about 34m. cannot receive echo
+            break
     time2 = time.time()
 
-    during = time2 - time1
-    return during * 340 / 2 * 100
+    duration = time2 - time1
+    return duration * 340 / 2 * 100 # cm
 
 def front_detection():
 
@@ -264,7 +268,7 @@ def back_detection():
 
     servo.turn_direction(3,90)
     time.sleep(0.5)
-    dis_b = distance(TRIG2, ECHO2) # need to wire ultrsound
+    dis_b = distance(TRIG2, ECHO2)
     return dis_b
 
 def left_detection():
@@ -341,7 +345,7 @@ def loop():
 
         distance_F = front_detection()
 
-        if distance_F < 40: # or near_verge or c_left or c_right or c_back_left or c_back_right:
+        if distance_F < SAFE_DISTANCE: # or near_verge or c_left or c_right or c_back_left or c_back_right:
             stop(0.2)
             move_backward(SPEED,0.2)
             stop(0.2)
@@ -349,8 +353,8 @@ def loop():
             distance_L = left_detection()
             distance_R = right_detection()
             
-            if (distance_L < 40) == True and (distance_R < 40) == True:
-                print('US LR < 40', distance_L, distance_R)
+            if (distance_L < SAFE_DISTANCE) == True and (distance_R < SAFE_DISTANCE) == True:
+                print('US LR < ' + str(SAFE_DISTANCE), distance_L, distance_R)
                 turn_left(SPEED,1)
             elif (distance_L > distance_R) == True:
                 print('US L > R', distance_L, distance_R)
