@@ -694,8 +694,8 @@ servo channels:
                 lcd2.noBacklight()
 
                 cols = 16
-                l1 = 'liquidcrystal_i2c'.center(cols)
-                l2 = '@hangzhou'.rjust(cols)
+                l1 = 'pip install pi4'.ljust(cols)
+                l2 = 'zhangys.org.cn'.rjust(cols)
                 for i in range(cols):
 
                     l1 = l1[-1] + l1[:-1]
@@ -794,22 +794,32 @@ servo channels:
         # reschedule to run again in 1 second
         self.after(delay, self.UpdateImage, INTERVAL) # frame rate
 
-    def measure_distance(self, front_only = True):
+    def measure_distance(self, flags = [1,0,0,1]):
+        '''
+        Measure distances to avoid collision. 
+        We cannot put this funciton in a side thread loop. Must use it in the main thread.
 
-        # while(True): # cannot do it in a thread
-
-        # inside this loop, we judge distance to avoid collision
-        self.distance_F = round(acc.front_detection())
+        flags : 4-bit flags for front, back, left and right detection
+        '''       
         
-        if not front_only:
+        if flags[0]:
+            self.distance_F = round(acc.front_detection())
+        if flags[1]:
+            self.distance_B = round(acc.back_detection())
+        if flags[2]:
             self.distance_L = round(acc.left_detection())
-            self.distance_R = round(acc.right_detection())
-            print(self.distance_F, self.distance_L, self.distance_R)
-
-        if self.distance_F < 20:
+        if flags[3]:
+            self.distance_R = round(acc.right_detection())        
+        
+        if self.distance_F < acc.SAFE_DISTANCE:
             acc.stop(0.2)
             acc.move_backward(t_time = 0.2)
-            acc.stop(0.2)        
+            acc.stop(0.2)   
+
+        if self.distance_B < acc.SAFE_DISTANCE:
+            acc.stop(0.2)
+            acc.move_forward(t_time = 0.2)
+            acc.stop(0.2)
 
     def get_image(self):
 
@@ -818,12 +828,8 @@ servo channels:
 
         if acc.RUNNING == False:
 
-            front_only = True
-            self.measure_distance(front_only=front_only) # update distances
-            if front_only:
-                s = "Distance : " + str(self.distance_F)
-            else:
-                s = "Distances : " + str(self.distance_L) + ', ' + str(self.distance_F) + ',' + str(self.distance_R)
+            self.measure_distance(flags=[1,1,0,0]) # update distances
+            s = "Distances[FBLR] = " + str(self.distance_F) + str(self.distance_B) + ', ' + str(self.distance_L) + ',' + str(self.distance_R)
             draw = ImageDraw.Draw(img)
             ft = ImageFont.truetype('FreeMono.ttf', 25)
             draw.text((10, 10), 
